summaryrefslogtreecommitdiff
path: root/gnu
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2012-08-09 18:19:46 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2012-08-09 18:19:46 +0000
commitc50e9b16a80795bdae5adb214e440c508877dd0a (patch)
treeb5c33aeda41915b7293d313cdb1bfd30b16edefa /gnu
parent9a604b529cd77429c0a7c815ac05bbb2a0b72361 (diff)
Recognize and silently eat -rpath-link, as already done for -rpath, to avoid
choking on the commandlines the base libtool builds.
Diffstat (limited to 'gnu')
-rw-r--r--gnu/usr.bin/ld/ld.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/gnu/usr.bin/ld/ld.c b/gnu/usr.bin/ld/ld.c
index 4c5923336ac..c2f0cfe3f7d 100644
--- a/gnu/usr.bin/ld/ld.c
+++ b/gnu/usr.bin/ld/ld.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ld.c,v 1.33 2008/02/12 21:17:53 miod Exp $ */
+/* $OpenBSD: ld.c,v 1.34 2012/08/09 18:19:45 miod Exp $ */
/* $NetBSD: ld.c,v 1.52 1998/02/20 03:12:51 jonathan Exp $ */
/*-
@@ -472,9 +472,12 @@ classify_arg(char *arg)
/* GNU binutils 2.x forward-compatible flags. */
case 'r':
- /* Ignore "-rpath" and hope ld.so.conf will cover our sins. */
+ /* Ignore "-rpath" and "-rpath-link" and hope ld.so.conf
+ will cover our sins. */
if (!strcmp(&arg[1], "rpath"))
return 2;
+ if (!strcmp(&arg[1], "rpath-link"))
+ return 2;
return 1;
case 's':